anvio user home

© 2015 Anvi'o Project.

#### New Project

Please provide a name and description for your project.

Project name *
Description

Please upload essential data files for visualization ('*' identifies mandatory files).

Tree *
Data
FASTA

Formatting of the following two files are explained here.

Samples order
Samples info

#### Upload additional / replacement data

Select the type of data you want to add / replace and the file to upload. Note that existing files in your project will be overwritten. This cannot be undone.

file type
data file

#### Share project

You can share your project with other users by link or you can make it publicly accessible to all users.

name
public

#### Project Information